==> jc-1.4.0.tar.gz: java/awt/Component__24BltBufferStrategy.h <==
// public class java.awt.Component$BltBufferStrategy

// class file dependencies
// @dep_class 271346591d3808f8 java_awt_Component__24BltBufferStrategy
// @dep_class 5615ecb69ad41bde java_awt_image_BufferStrategy
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_BufferStrategy

#include "java/awt/image/BufferStrategy.h"

#ifndef _JC_java_awt_Component__24BltBufferStrategy_H_
#define _JC_java_awt_Component__24BltBufferStrategy_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24BltBufferStrategy$sub_refs	_jc_java_awt_Component__24BltBufferStrategy$sub_refs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs	_jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$refs	_jc_java_awt_Component__24BltBufferStrategy$refs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$nonrefs	_jc_java_awt_Component__24BltBufferStrategy$nonrefs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$object	_jc_java_awt_Component__24BltBufferStrategy$object;

typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vmethods	_jc_java_awt_Component__24BltBufferStrategy$vmethods;
typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vtable	_jc_java_awt_Component__24BltBufferStrategy$vtable;
typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vtype	_jc_java_awt_Component__24BltBufferStrategy$vtype;

// Constructors
extern void _jc_java_awt_Component__24BltBufferStrategy$method$_init$a08c88b92974c017(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_BufferCapabilities$object *);

// Virtual methods
extern jboolean _jc_java_awt_Component__24BltBufferStrategy$method$contentsLost$43f368939717a903(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
extern jboolean _jc_java_awt_Component__24BltBufferStrategy$method$contentsRestored$524d1efb1bd23576(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
extern void _jc_java_awt_Component__24BltBufferStrategy$method$createBackBuffers$ff72c7f9e96fe25c(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, jint);
extern struct _jc_java_awt_BufferCapabilities$object *_jc_java_awt_Component__24BltBufferStrategy$method$getCapabilities$bc677871f5d762f9(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_Component__24BltBufferStrategy$method$getDrawGraphics$e9804cf8fbb1d8bd(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
extern void _jc_java_awt_Component__24BltBufferStrategy$method$revalidate$8f9aa0fe4941bc1c(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
extern void _jc_java_awt_Component__24BltBufferStrategy$method$show$8844e066fe447d0e(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$contentsLost$43f368939717a903;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$contentsRestored$524d1efb1bd23576;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$createBackBuffers$ff72c7f9e96fe25c;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$getCapabilities$bc677871f5d762f9;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$getDrawGraphics$e9804cf8fbb1d8bd;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$revalidate$8f9aa0fe4941bc1c;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_java_awt_Component__24BltBufferStrategy$vmethods {
	jboolean	(*contentsLost$43f368939717a903)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
	jboolean	(*contentsRestored$524d1efb1bd23576)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
	void	(*createBackBuffers$ff72c7f9e96fe25c)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, jint);
	struct _jc_java_awt_BufferCapabilities$object	*(*getCapabilities$bc677871f5d762f9)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
	struct _jc_java_awt_Graphics$object	*(*getDrawGraphics$e9804cf8fbb1d8bd)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
	void	(*revalidate$8f9aa0fe4941bc1c)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *);
};

// Vtable
struct _jc_java_awt_Component__24BltBufferStrategy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferStrategy$vmethods	java_awt_image_BufferStrategy;
	_jc_java_awt_Component__24BltBufferStrategy$vmethods	java_awt_Component__24BltBufferStrategy;
};

// Vtype
struct _jc_java_awt_Component__24BltBufferStrategy$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24BltBufferStrategy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24BltBufferStrategy$sub_refs {
	struct _jc_java_awt_BufferCapabilities$object	*caps;
	_jc_object_array	*backBuffers;
	struct _jc_java_awt_Component$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24BltBufferStrategy$refs {
    _jc_java_awt_Component__24BltBufferStrategy$sub_refs	java_awt_Component__24BltBufferStrategy;
    _jc_java_awt_image_BufferStrategy$sub_refs	java_awt_image_BufferStrategy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs {
	jboolean	validatedContents;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24BltBufferStrategy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferStrategy$sub_nonrefs	java_awt_image_BufferStrategy;
    _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs	java_awt_Component__24BltBufferStrategy;
};

// Object instance structure
struct _jc_java_awt_Component__24BltBufferStrategy$object {
	_jc_java_awt_Component__24BltBufferStrategy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24BltBufferStrategy$vtype	*vtype;
	_jc_java_awt_Component__24BltBufferStrategy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24BltBufferStrategy$vtype _jc_java_awt_Component__24BltBufferStrategy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24BltBufferStrategy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24BltBufferStrategy$class_object;

#endif	/* _JC_java_awt_Component__24BltBufferStrategy_H_ */

==> jc-1.4.5.tar.gz: java/awt/Component__24BltBufferStrategy.h <==
// public class java.awt.Component$BltBufferStrategy

// class file dependencies
// @dep_class 352db1a81ee24ce4 java_awt_Component__24BltBufferStrategy
// @dep_class 5615ecb69ad41bde java_awt_image_BufferStrategy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_BufferStrategy

#include "java/awt/image/BufferStrategy.h"

#ifndef _JC_java_awt_Component__24BltBufferStrategy_H_
#define _JC_java_awt_Component__24BltBufferStrategy_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24BltBufferStrategy$sub_refs	_jc_java_awt_Component__24BltBufferStrategy$sub_refs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs	_jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$refs	_jc_java_awt_Component__24BltBufferStrategy$refs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$nonrefs	_jc_java_awt_Component__24BltBufferStrategy$nonrefs;
typedef struct _jc_java_awt_Component__24BltBufferStrategy$object	_jc_java_awt_Component__24BltBufferStrategy$object;

typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vmethods	_jc_java_awt_Component__24BltBufferStrategy$vmethods;
typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vtable	_jc_java_awt_Component__24BltBufferStrategy$vtable;
typedef const struct _jc_java_awt_Component__24BltBufferStrategy$vtype	_jc_java_awt_Component__24BltBufferStrategy$vtype;

// Constructors
extern void _jc_java_awt_Component__24BltBufferStrategy$method$_init$a08c88b92974c017(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, struct _jc_java_awt_Component$object *, jint, struct _jc_java_awt_BufferCapabilities$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_Component__24BltBufferStrategy$method$contentsLost$43f368939717a903(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_Component__24BltBufferStrategy$method$contentsRestored$524d1efb1bd23576(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24BltBufferStrategy$method$createBackBuffers$ff72c7f9e96fe25c(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_BufferCapabilities$object *_jc_java_awt_Component__24BltBufferStrategy$method$getCapabilities$bc677871f5d762f9(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_java_awt_Component__24BltBufferStrategy$method$getDrawGraphics$e9804cf8fbb1d8bd(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24BltBufferStrategy$method$revalidate$8f9aa0fe4941bc1c(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24BltBufferStrategy$method$show$8844e066fe447d0e(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$contentsLost$43f368939717a903;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$contentsRestored$524d1efb1bd23576;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$createBackBuffers$ff72c7f9e96fe25c;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$getCapabilities$bc677871f5d762f9;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$getDrawGraphics$e9804cf8fbb1d8bd;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$revalidate$8f9aa0fe4941bc1c;
extern _jc_method _jc_java_awt_Component__24BltBufferStrategy$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_java_awt_Component__24BltBufferStrategy$vmethods {
	jboolean	(*contentsLost$43f368939717a903)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
	jboolean	(*contentsRestored$524d1efb1bd23576)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
	void	(*createBackBuffers$ff72c7f9e96fe25c)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_awt_BufferCapabilities$object	*(*getCapabilities$bc677871f5d762f9)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getDrawGraphics$e9804cf8fbb1d8bd)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
	void	(*revalidate$8f9aa0fe4941bc1c)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_java_awt_Component__24BltBufferStrategy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Component__24BltBufferStrategy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferStrategy$vmethods	java_awt_image_BufferStrategy;
	_jc_java_awt_Component__24BltBufferStrategy$vmethods	java_awt_Component__24BltBufferStrategy;
};

// Vtype
struct _jc_java_awt_Component__24BltBufferStrategy$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24BltBufferStrategy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24BltBufferStrategy$sub_refs {
	struct _jc_java_awt_BufferCapabilities$object	*caps;
	_jc_object_array	*backBuffers;
	struct _jc_java_awt_Component$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24BltBufferStrategy$refs {
    _jc_java_awt_Component__24BltBufferStrategy$sub_refs	java_awt_Component__24BltBufferStrategy;
    _jc_java_awt_image_BufferStrategy$sub_refs	java_awt_image_BufferStrategy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs {
	jboolean	validatedContents;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24BltBufferStrategy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferStrategy$sub_nonrefs	java_awt_image_BufferStrategy;
    _jc_java_awt_Component__24BltBufferStrategy$sub_nonrefs	java_awt_Component__24BltBufferStrategy;
};

// Object instance structure
struct _jc_java_awt_Component__24BltBufferStrategy$object {
	_jc_java_awt_Component__24BltBufferStrategy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24BltBufferStrategy$vtype	*vtype;
	_jc_java_awt_Component__24BltBufferStrategy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24BltBufferStrategy$vtype _jc_java_awt_Component__24BltBufferStrategy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24BltBufferStrategy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24BltBufferStrategy$class_object;

#endif	/* _JC_java_awt_Component__24BltBufferStrategy_H_ */
